## 每日筹码分布

接口：cyq_chips

描述：获取A股每日的筹码分布情况，提供各价位占比，数据从2018年开始，每天17~18点之间更新当日数据

来源：Tushare社区

限量：单次最大2000条，可以按股票代码和日期循环提取

积分：120积分可以试用查看数据，5000积分每天20000次，10000积分每天200000次，15000积分每天不限总量

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（YYYYMMDD） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| price | float | Y | 成本价格 |
| percent | float | Y | 价格占比（%） |

接口用法

```python
pro = ts.pro_api()

df = pro.cyq_chips(ts_code='600000.SH', start_date='20220101', end_date='20220429')
```

数据样例

```python
ts_code trade_date price percent
0    600000.SH   20220429  8.96    0.56
```